﻿using System.Collections.Generic;

namespace Text_Adventure_Tutorial
{
	public class Location
    {
        /// <summary>
        /// This class is used to create the locations in the game world
        /// It has a dictionary of Items in that location which can be
        /// added in the constructor, or as the player drops items as he/she goes along.
        /// 
        /// There are string LocationToXXX directions which determine whether there is an
        /// entrance / exit in that direction. The string is the dictionary key to another Location
        /// </summary>
        
        #region Public Properties
        public string Name { get; set; } 
		public string DisplayName { get; set; }        
        public string Description { get; set; }
        public string LocationToNorth { get; set; }
        public string LocationToEast { get; set; }
        public string LocationToSouth { get; set; }
        public string LocationToWest { get; set; }
        public Dictionary<string, Item> Items { get; set; } = new Dictionary<string, Item>();
        public Item ItemRequired {get; set;}
        #endregion
        #region Constructor
        public Location(string name,
                        string displayname,
                        string description,
                        string locationToNorth = "",
                        string locationToEast = "",
                        string locationToSouth = "",
                        string locationToWest = "",
                        List<Item> listitem = null,
                       	Item itemRequired = null)
        {
        	Name = name;
            DisplayName = displayname;
            Description = description;
            LocationToNorth = locationToNorth;
            LocationToEast = locationToEast;
            LocationToSouth = locationToSouth;
            LocationToWest = locationToWest;
            if (listitem != null)
                CreateDictionary(listitem);
            ItemRequired = itemRequired;
        }
        #endregion
        #region Methods
        public void AddItem(Item item)
        {
            Items.Add(item.Name, item);
        }
        public void RemoveItem(Item item)
        {
            Items.Remove(item.Name);
        }
        public void RemoveItem(string itemName)
        {
            Items.Remove(itemName);
        }
        private void CreateDictionary(List<Item> itemList)
        {
            /// Used from the constructor to convert a list of Items into a Dictionary
            foreach(Item item in itemList)
            {
                Items.Add(item.Name, item);
            }
        }
        #endregion
    }
}
